@@ -232,13 +232,18 @@ class Collection(BaseModel):
         return object.__getattribute__(self, attr)        
 
         
-def create_collection(name:str):
+def create_collection(name:str, team_name=None):
     """
     Create a collection of the specified name
     Returns a Collection object.
     Raises ClientError if the specified name already exists
+
+    'team_obj_or_name' is optional and can be either a team name or team object.
+    if team is unspecified the user's default team will be used.
     """
     data = {'name': name}
+    if team_name:
+        data['team_id'] = team(team_name).id
     resp = session.post("/collections", json=data)
     return Collection(**resp.json())
 
@@ -251,9 +256,10 @@ def collection(name:str):
     data = {'name': name}
     resp = session.get(f"/collections?{urllib.parse.urlencode(data)}")
     items = resp.json()['items']
-    assert(len(items) <= 1)
     if len(items):
         return Collection(**items[0])
+    raise Exception(f"Collection {name} not found")
+
 
 def all_collections():
     resp = session.get("/collections")
@@ -308,6 +314,35 @@ class Index(BaseModel):
         return ix
 
 
+###
+##  Teams
+###
+class Team(BaseModel):
+    id: int = Field(description="Internal team id")
+    name: str = Field(min_length=3, max_length=39, description='Unique name for this team.')
+    description: Optional[str] = Field(default=None, description='Optional user supplied description.')
+    created_at: float = Field(description='The epoch timestamp when the team was created.')
+    updated_at: float = Field(description='The epoch timestamp when the team was updated.')
+
+
+def all_teams():
+    """
+    return all Teams that the user is a member of
+    """
+    resp = session.get("/teams")
+    return [Team(**i) for i in resp.json()['items']]
+
+def team(name):
+    """
+    get team by name
+    raises Exception if an exact match for name is not found
+    """
+    team = [t for t in session.get("/teams").json()['items'] if t['name'] == name]
+    if len(team):
+        return Team(**team[0])
+    raise Exception(f"Team '{name}' not found")
+
+
 def init(host    = os.environ.get("JIGGY_HOST",    "https://api.jiggy.ai"),
          version = os.environ.get("JIGGY_VERSION", "jiggy-v0")):
     global session
